@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.16
+# Version   : 0.2.17
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -579,7 +579,7 @@ class AFM:
                 adjusted_retract =  np.append(adjusted_retract, blank)
                 _z_w = np.append(_z_w, blank)
 
-            if len(z_approach_raw) < 10 or len(z_withdraw_raw) < 10 or len(approachraw) < 10 or len(retract_raw) < 10 :
+            if len(adjusted_approach) < 10 or len(adjusted_retract) < 10 :
                 break
 
             if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
